"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertToWebp = convertToWebp;
exports.convertToAvif = convertToAvif;

var _sharp = _interopRequireDefault(require("sharp"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _findCacheDir = _interopRequireDefault(require("find-cache-dir"));

var _createHash = _interopRequireDefault(require("webpack/lib/util/createHash"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const hashCache = new WeakMap();

_sharp.default.cache(false);

function hashBuffer(data) {
  const cached = hashCache.get(data);

  if (cached != null) {
    return cached;
  }

  const result = (0, _createHash.default)('xxhash64').update(data).digest('hex');
  hashCache.set(data, result);
  return result;
}

class FsCache {
  constructor() {
    _defineProperty(this, "_path", void 0);

    this._path = (0, _findCacheDir.default)({
      name: 'web-image-loader',
      create: true
    });
  }

  async get(key) {
    if (this._path == null) {
      return null;
    }

    try {
      return await _fs.default.promises.readFile(_path.default.join(this._path, key));
    } catch (ex) {
      return null;
    }
  }

  async set(key, value) {
    if (this._path == null) {
      return;
    }

    await _fs.default.promises.writeFile(_path.default.join(this._path, key), value);
  }

}

const cache = new FsCache();

async function convertToWebp(image) {
  const key = hashBuffer(image) + '.webp';
  const cached = await cache.get(key);

  if (cached != null) {
    return cached;
  }

  const result = await (0, _sharp.default)(image).webp({
    quality: 70
  }).toBuffer();
  await cache.set(key, result);
  return result;
}

async function convertToAvif(image) {
  const key = hashBuffer(image) + '.avif';
  const cached = await cache.get(key);

  if (cached != null) {
    return cached;
  }

  const result = await (0, _sharp.default)(image).avif({
    quality: 55,
    speed: 7
  }).toBuffer();
  await cache.set(key, result);
  return result;
}
//# sourceMappingURL=Converter.js.map