"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createImageWrapper = createImageWrapper;

var _groupBy = _interopRequireDefault(require("lodash/groupBy"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const SORT = ['image/webp', 'image/avif'];

function createImageWrapper(classPath, esModule) {
  return (size, images) => {
    const imagesByType = (0, _groupBy.default)(images, img => img.type); // Template strings are a bit weird here but this is the price
    // to pay to make the generated code beautiful :S

    const sources = `[
    ${Object.values(imagesByType) // Make sure avif then webp comes first.
    .sort((a, b) => {
      const ia = SORT.indexOf(a[0].type);
      const ib = SORT.indexOf(b[0].type);
      return ib - ia;
    }).map(group => `{
      srcSet: ${group.map(img => `${img.publicPath} + " ${img.scale}x"`).join(' + "," +\n        ')},
      type: "${group[0].type}"
    }`).join(',\n    ')}
  ]`;
    return `${esModule ? `import {AdaptiveImage} from ${classPath}` : `var AdaptiveImage = require(${classPath}).AdaptiveImage`};

${esModule ? 'export default' : 'module.exports ='} new AdaptiveImage({
  uri: ${images[0].publicPath},
  width: ${size.width},
  height: ${size.height},
  sources: ${sources}
});
`;
  };
}
//# sourceMappingURL=ImageWrapper.js.map