"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = resolve;
exports.raw = void 0;

var _loaderUtils = _interopRequireDefault(require("loader-utils"));

var _path = _interopRequireDefault(require("path"));

var _schemaUtils = require("schema-utils");

var _ImageResolver = require("./ImageResolver");

var _ImageWrapper = require("./ImageWrapper");

var _options = _interopRequireDefault(require("./options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_IMAGE_CLASS_PATH = require.resolve('./AdaptiveImage');

const DEFAULT_IMAGE_NAME_FORMAT = '[hash][scale].[ext]';
const DEFAULT_SCALINGS = [1, 2, 3];

function interpolateName(context, nameFormat, content, scale) {
  return _loaderUtils.default.interpolateName(context, nameFormat, {
    context: context.context,
    content
  }).replace(/\[scale\]/g, scale === 1 ? '' : `@${scale}x`);
}

function emitAndResolveImage(context, options, file, content) {
  var _options$name;

  const nameFormat = (_options$name = options.name) !== null && _options$name !== void 0 ? _options$name : DEFAULT_IMAGE_NAME_FORMAT;
  let fileName = interpolateName(context, nameFormat, content, file.scale);

  if (file.type === 'image/webp') {
    fileName = fileName.replace(/\.png|\.jpe?g/, '.webp');
  }

  if (file.type === 'image/avif') {
    fileName = fileName.replace(/\.png|\.jpe?g/, '.avif');
  }

  let outputPath = fileName;

  if (options.outputPath) {
    outputPath = _path.default.posix.join(options.outputPath, fileName);
  }

  let publicPath = `__webpack_public_path__ + ${JSON.stringify(outputPath)}`;

  if (options.publicPath) {
    if (typeof options.publicPath === 'function') {
      publicPath = options.publicPath(fileName, file.uri);
    } else {
      publicPath = `${options.publicPath.endsWith('/') ? options.publicPath : `${options.publicPath}/`}${fileName}`;
    }

    publicPath = JSON.stringify(publicPath);
  }

  context.emitFile(outputPath, content, null);
  return {
    outputPath,
    publicPath,
    type: file.type,
    scale: file.scale
  };
}

async function resolve(content) {
  var _options$scalings, _options$formats$avif, _options$formats, _options$formats$webp, _options$formats2;

  const callback = this.async();

  const options = _loaderUtils.default.getOptions(this);

  (0, _schemaUtils.validate)(_options.default, options, {
    name: 'React Native Web Image Loader',
    baseDataPath: 'options'
  });
  const esModule = typeof options.esModule !== 'undefined' ? options.esModule : false;
  const scalings = (_options$scalings = options.scalings) !== null && _options$scalings !== void 0 ? _options$scalings : DEFAULT_SCALINGS;
  const formats = {
    avif: (_options$formats$avif = (_options$formats = options.formats) === null || _options$formats === void 0 ? void 0 : _options$formats.avif) !== null && _options$formats$avif !== void 0 ? _options$formats$avif : true,
    webp: (_options$formats$webp = (_options$formats2 = options.formats) === null || _options$formats2 === void 0 ? void 0 : _options$formats2.webp) !== null && _options$formats$webp !== void 0 ? _options$formats$webp : true
  };
  const wrapImage = (0, _ImageWrapper.createImageWrapper)(_loaderUtils.default.stringifyRequest(this, options.imageClassPath || DEFAULT_IMAGE_CLASS_PATH), esModule);

  try {
    const resolvedImages = [];
    const size = await (0, _ImageResolver.resolveImage)(this.resourcePath, content, scalings, formats, (file, fileContent) => {
      resolvedImages.push(emitAndResolveImage(this, options, file, fileContent));
    });
    const result = wrapImage(size, resolvedImages);
    callback(null, result);
  } catch (e) {
    callback(e);
  }
}

resolve.raw = true;
const raw = true;
exports.raw = raw;
//# sourceMappingURL=index.js.map